use dirs::config_dir;
use serde::Deserialize;
use std::fs;
use std::path::PathBuf;

#[derive(Debug, Deserialize)]
pub struct Config {
    pub weather_api_key: String,
    pub pollen_api_key: String,
    pub calendar_api_key: String,
    pub shopify_api_key: String,
    pub shopify_store: String,
    pub calendar_event_count: usize,
    pub location: String,
    pub timezone: String,
}

impl Config {
    pub fn load() -> Result<Self, Box<dyn std::error::Error>> {
        // Try primary platform config_dir first (macOS: ~/Library/Application Support/trmnl/config.toml, Linux: ~/.config/trmnl/config.toml)
        let mut config_path = config_dir().ok_or("Could not find user config directory")?;
        config_path.push("trmnl/config.toml");
        if config_path.exists() {
            let contents = fs::read_to_string(&config_path)?;
            let config: Config = toml::from_str(&contents)?;
            return Ok(config);
        }
        // Fallback: try ~/.config/trmnl/config.toml explicitly
        if let Some(home_dir) = dirs::home_dir() {
            let fallback_path: PathBuf = home_dir.join(".config/trmnl/config.toml");
            if fallback_path.exists() {
                let contents = fs::read_to_string(&fallback_path)?;
                let config: Config = toml::from_str(&contents)?;
                return Ok(config);
            }
        }
        Err("Config file not found in either location".into())
    }
}
